/***************************************************************************
                          kmuddocker.cpp
                      -------------------
    description          :
    begin                : Fri Jul 28 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "kmuddocker.h"
#include <kwm.h>

KmudDocker::KmudDocker(QWidget *kmud_main_widget, const QPixmap& tray_icon)
                         :QLabel(NULL, "KmudDocker")
{
  kmud_app = kmud_main_widget;
  setPixmap(tray_icon);
  KWM::setDockWindow(winId());
}

KmudDocker::~KmudDocker()
{
}

void KmudDocker::mousePressEvent(QMouseEvent* event)
{
  // when the kmud window is hidden restore it
  if (!kmud_app->isVisible())
  {
    kmud_app->show();
  }
}
